Learn R Programming

DOBAD (version 1.0.6)

CTMC_PO_many-class: Class "CTMC_PO_many"

Description

~~ A concise (1-5 lines) description of what the class is. ~~

Arguments

Objects from the Class

Objects can be created by calls of the form new("CTMC_PO_many", ...). This class is a grouping of data, essentially. CTMC_PO_1 is a series of observations from a single chain; this is several of those single observations together.

Slots

BDMCsPO:

Object of class "list" ~~

Methods

No methods defined with class "CTMC_PO_many" in the signature.

Examples

Run this code
# NOT RUN {
showClass("CTMC_PO_many")
# }

Run the code above in your browser using DataLab