Learn R Programming

DOBAD (version 1.0.6)

getDataSummary.CTMC_PO_many: Calculate Some Summarizing Information for the Given Data

Description

Computes some summarizing statistics for a CTMC_PO_many object and returns them, possibly also saving them to a file.

Usage

getDataSummary.CTMC_PO_many(dat, file = "dataSummary.rsav")

Arguments

dat

Discretely Observed BDI process.

file

Filename to save to.

Details

See the function definition for the variable names used. Saving and loading to/from a file seemed like the simplest approach.