Assume we have data that is the state at discrete time points of a linear birth-death process, which has immigration parameter constrained to be a known constant times the birth rate. After using EM Algorithm for estimating rate parameters of a linear Birth-Death process, this function gives the information matrix associated.
getBDinform.PO.SC(partialData,Lhat,Mhat, beta.immig,delta=.001,
n=1024,r=4, prec.tol=1e-12,prec.fail.stop=TRUE)MLE for lambda, the birth rate.
MLE for mu, the death rate.
Immigration rate is constrained to be a multiple of the birth rate. immigrationrate = beta.immig * lambda where lambda is birth rate.
Partially observed chain. CTMC_PO_1 or CTMC_PO_many
n for riemann integral approximatoin.
see help for, say, all.cond.mean.PO
Symmetric 2x2 matrix; First row/column corresponds to lambda, second corresponds to mu
Assume we have a linear-birth-death process \(X_t\) with birth parameter \(\lambda\), death parameter \(\mu\), and immigration parameter \(\beta \lambda\) (for some known, real \(\beta\)). We observe the process at a finite set of times over a time interval [0,T]. After running the EM algorithm to do estimation, this function returns the information to get, for instance, asymptotic CIs.
See the Louis paper for the method.
To calculate the information matrix, the expecatations of the products of the sufficient statistics, conditional on the data, are needed. They are calculated by Monte Carlo, and N is the number of simulations to run.