Computes some summarizing statistics for a CTMC_PO_many object and returns them, possibly also saving them to a file.
getDataSummary.CTMC_PO_many(dat, file = "dataSummary.rsav")Discretely Observed BDI process.
Filename to save to.
See the function definition for the variable names used. Saving and loading to/from a file seemed like the simplest approach.